@@ -2,13 +2,13 @@
 
 import os
 import sys
-import glob
 import subprocess
+from collections import OrderedDict
 
 import click
 
 from EulerPy.problem import Problem
-from EulerPy.utils import clock, format_time, rename_file
+from EulerPy.utils import clock, format_time, problem_glob, rename_file
 
 
 # --cheat / -c
@@ -43,6 +43,10 @@ def generate(p, prompt_default=True):
 
     click.secho('Successfully created "{0}".'.format(p.filename), fg='green')
 
+    # Copy over problem resources if required
+    if p.resources:
+        p.copy_resources()
+
 
 # --preview / -p
 def preview(p):
@@ -78,7 +82,7 @@ def verify(p, filename=None, exit=True):
     solution = p.solution
     click.echo('Checking "{0}" against solution: '.format(filename), nl=False)
 
-    cmd = [sys.executable or 'python', filename]
+    cmd = (sys.executable or 'python', filename)
     start = clock()
     proc = subprocess.Popen(cmd, stdout=subprocess.PIPE)
     stdout = proc.communicate()[0]
@@ -130,24 +134,32 @@ def verify_all(current_p):
     """
 
     # Define various problem statuses
-    status = {
-        'correct': click.style('C', fg='green', bold=True),
-        'incorrect': click.style('I', fg='red', bold=True),
-        'error': click.style('E', fg='yellow', bold=True),
-        'skipped': click.style('S', fg='cyan', bold=True),
-        'missing': click.style('.', fg='white', bold=True),
-    }
+    keys = ('correct', 'incorrect', 'error', 'skipped', 'missing')
+    symbols = ('C', 'I', 'E', 'S', '.')
+    colours = ('green', 'red', 'yellow', 'cyan', 'white')
+
+    status = OrderedDict(
+        (key, click.style(symbol, fg=colour, bold=True))
+        for key, symbol, colour in zip(keys, symbols, colours)
+    )
 
     overview = {}
 
     # Search through problem files using glob module
-    for filename in glob.glob('[0-9][0-9][0-9]*.py'):
-        p = Problem(int(filename[:3]))
+    files = problem_glob()
+
+    # No Project Euler files in the current directory
+    if not files:
+        click.echo("No Project Euler files found in the current directory.")
+        sys.exit(1)
+
+    for file in files:
+        p = Problem(int(file[:3]))
 
         # Catch KeyboardInterrupt during verification to allow the user
         # to skip the verification of a problem if it takes too long
         try:
-            is_correct = verify(p, filename=filename, exit=False)
+            is_correct = verify(p, filename=file, exit=False)
         except KeyboardInterrupt:
             overview[p.num] = status['skipped']
         else:
@@ -163,20 +175,13 @@ def verify_all(current_p):
                 # when the --verify-all is used in a directory containing
                 # files generated pre-v1.1 (before files with suffixes)
                 if p.num != current_p.num:
-                    rename_file(filename, p.suf_name('skipped'))
+                    rename_file(file, p.suf_name('skipped'))
 
         # Separate each verification with a newline
         click.echo()
 
-    # No Project Euler files in the current directory
-    if not overview:
-        click.echo("No Project Euler files found in the current directory.")
-        sys.exit(1)
-
     # Print overview of the status of each problem
-    legend = ', '.join('{0} = {1}'.format(status[key], key) for key in
-        ('correct', 'incorrect', 'error', 'skipped', 'missing')
-    )
+    legend = ', '.join('{0} = {1}'.format(v, k) for k, v in status.items())
 
     click.echo('-' * 63)
     click.echo(legend + '\n')
@@ -229,7 +234,7 @@ def main(option, problem):
     # No problem given (or given option ignores the problem argument)
     if problem == 0 or option in (skip, verify_all):
         # Determine the highest problem number in the current directory
-        files = glob.glob('[0-9][0-9][0-9]*.py')
+        files = problem_glob()
         problem = max(int(file[:3]) for file in files) if files else 0
 
         # No Project Euler files in current directory (no glob results)
@@ -249,15 +254,15 @@ def main(option, problem):
 
         # No option and no problem; generate next file if answer is
         # correct (verify() will exit if the solution is incorrect)
-        if not option:
+        if option is None:
             verify(Problem(problem))
             problem += 1
             option = generate
 
     # Problem given but no option; decide between generate and verify
-    elif not option:
+    elif option is None:
         option = verify if any(Problem(problem).iglob) else generate
 
     # Execute function based on option (pass Problem object as argument)
     option(Problem(problem))
-    sys.exit()
+    sys.exit(0)
